
// Copyright (C) 2002-2011 Nikolaus Gebhardt
// This file is part of the "Irrlicht Engine".
// For conditions of distribution and use, see copyright notice in irrlicht.h

#ifndef __IRR_C_TEXTURE_MANAGER_H_INCLUDED__
#define __IRR_C_TEXTURE_MANAGER_H_INCLUDED__


#include



namespace irr
{

namespace video
{



//template <class TEXTURE>
class CTextureManager
{
public:
        CTextureManager( IImageManager* );

		//! Removes a texture from the texture cache and deletes it, freeing lot of
		//! memory.
		virtual void removeTexture(ITexture* texture);

		//! Removes all texture from the texture cache and deletes them, freeing lot of
		//! memory.
		virtual void removeAllTextures();

        virtual IImageManager* getImageManager() const;

    private:
		struct SSurface
		{
			video::ITexture* Surface;

			bool operator < (const SSurface& other) const
			{
				return Surface->getName() < other.Surface->getName();
			}
		};

		struct SMaterialRenderer
		{
			core::stringc Name;
			IMaterialRenderer* Renderer;
		};

        // public ITexture
		struct SDummyTexture : public ITexture
		{
			SDummyTexture(const io::path& name) : ITexture(name), size(0,0) {};

			virtual void* lock(E_TEXTURE_LOCK_MODE mode=ETLM_READ_WRITE, u32 mipmapLevel=0) { return 0; };
			virtual void unlock(){}
			virtual const core::dimension2d<u32>& getOriginalSize() const { return size; }
			virtual const core::dimension2d<u32>& getSize() const { return size; }
			virtual E_DRIVER_TYPE getDriverType() const { return video::EDT_NULL; }
			virtual IVideoContext* getContext() const { return 0; }
			virtual ECOLOR_FORMAT getColorFormat() const { return video::ECF_A1R5G5B5; };
			virtual u32 getPitch() const { return 0; }
			virtual void regenerateMipMapLevels(void* mipmapData=0) {};
			core::dimension2d<u32> size;
		};
		core::array<SSurface> Textures;
        IImageManager* ImageManager;
};

}
}


#endif
